extends CanvasLayer

@onready var Pause_Sequence : AnimationPlayer = $Pause_Sequences;
@onready var Quit_Sequence : AnimationPlayer = $Quit_Sequences;
@onready var Options_Sequence : AnimationPlayer = $Options_Sequens;
@onready var Quit_Button : Button = $Quit_Button;
@onready var Option_Button : Button = $Options_Button;
@onready var Animation_Manager_Pause : String = "Pause";
@onready var Animation_Manager_Quit : String = "Quit";
@onready var Animation_Manager_Options : String = "Options";

@onready var Pause_Screen : Sprite2D = $Pause;
@onready var Mouse_Cursor := preload("res://Source/Images/lacey_pointer.png")
@onready var Youtube_Scroll : Camera2D = $"../Youtube_Scroll";
@onready var Youtube_Layout : Sprite2D = $"../Youtube_Layout";
@onready var Youtube_Layout_Top : Sprite2D = $"../YoutubeLayoutTop";

@onready var Subtitles_BG : Panel = $"../Subtitles_UI/Subtitles_BG"

@onready var Back_Button : TextureButton = $Options/Back;
@onready var Fullscreen : CheckBox = $Options/Fullscreen;
@onready var Cursor_Style : CheckBox = $Options/Cursor_Style;
@onready var Youtube_Layout_Button : CheckBox = $Options/Youtube_Layout;
@onready var Dark_Mode : CheckBox = $Options/Dark_Mode;
@onready var Background : Sprite2D = $Options;

@onready var Subtitles : CheckBox = $Options/Subtitles;

@onready var Mobile_Pause_Button : TextureButton = $Mobile_Pause_Button;

func _ready() -> void:
	
	if Global.Mobile_Input:
		Pause_Screen.texture = preload("res://Source/Images/pause_Mobile.png");
		Background.texture = preload("res://Source/Images/Game_Launcher_Assets/options_mobile.png");
		Mobile_Pause_Button.visible = true;
		Youtube_Layout_Button.position.y = -72;
		Dark_Mode.position.y = -23;
		Subtitles.position.y = 86;
		Fullscreen.visible = false;
		Cursor_Style.visible = false;
		Quit_Button.visible = false;
	
	if Global.Fullscreen:
		Fullscreen.button_pressed = true;
	else:
		Fullscreen.button_pressed = false;
		
	if Global.Cursor_Style:
		Cursor_Style.button_pressed = true;
	else:
		Cursor_Style.button_pressed = false;
		
	if Global.Youtube_Layout:
		Youtube_Layout_Button.button_pressed = true;
	else:
		Youtube_Layout_Button.button_pressed = false;
		
	if Global.Dark_Mode:
		Dark_Mode.button_pressed = true;
	else:
		Dark_Mode.button_pressed = false;

	if Global.Subtitles:
		Subtitles.button_pressed = true;
	else:
		Subtitles.button_pressed = false;
	

func _input(event: InputEvent) -> void:
	if event.is_action_pressed("Pause") && !Pause_Sequence.is_playing() && !Quit_Sequence.is_playing() && Animation_Manager_Quit == "Quit" && !Options_Sequence.is_playing() && Animation_Manager_Options == "Options" && !Global.Mobile_Input:
		get_tree().paused = true;
		if Animation_Manager_Pause == "UnPause":
			Quit_Button.mouse_filter = Control.MOUSE_FILTER_IGNORE;
			Option_Button.mouse_filter = Control.MOUSE_FILTER_IGNORE;
		Pause_Sequence.play(Animation_Manager_Pause);
	elif event.is_action_pressed("N") && !Pause_Sequence.is_playing() && !Quit_Sequence.is_playing() && Animation_Manager_Quit == "UnQuit" && !Options_Sequence.is_playing() && Animation_Manager_Options == "Options":
		Quit_Sequence.play(Animation_Manager_Quit);
		Animation_Manager_Quit = "Quit";
	elif event.is_action_pressed("Y") && !Pause_Sequence.is_playing() && !Quit_Sequence.is_playing() && Animation_Manager_Quit == "UnQuit" && !Options_Sequence.is_playing() && Animation_Manager_Options == "Options":
		get_tree().quit();
		
func _on_pause_sequences_animation_finished(anim_name: StringName) -> void:
	if anim_name == "Pause":
		Quit_Button.mouse_filter = Control.MOUSE_FILTER_STOP;
		Option_Button.mouse_filter = Control.MOUSE_FILTER_STOP;
		Animation_Manager_Pause = "UnPause";
	else:
		get_tree().paused = false;
		Animation_Manager_Pause = "Pause";

func _on_quit_button_pressed() -> void:
	if !Pause_Sequence.is_playing() && Animation_Manager_Pause == "UnPause" && Animation_Manager_Quit == "Quit" && !Quit_Sequence.is_playing() && !Options_Sequence.is_playing() && Animation_Manager_Options == "Options":
		Quit_Sequence.play(Animation_Manager_Quit);
		Animation_Manager_Quit = "UnQuit";


func _on_options_button_pressed() -> void:
	if !Pause_Sequence.is_playing() && Animation_Manager_Pause == "UnPause" && Animation_Manager_Quit == "Quit" && !Quit_Sequence.is_playing() && !Options_Sequence.is_playing() && Animation_Manager_Options == "Options":
		Option_Button.mouse_filter = Control.MOUSE_FILTER_IGNORE;
		Options_Sequence.play(Animation_Manager_Options);
		Animation_Manager_Options = "UnOptions";

func _on_back_pressed() -> void:
	if !Pause_Sequence.is_playing() && Animation_Manager_Pause == "UnPause" && Animation_Manager_Quit == "Quit" && !Quit_Sequence.is_playing() && !Options_Sequence.is_playing() && Animation_Manager_Options == "UnOptions":
		Options_Sequence.play(Animation_Manager_Options);
		Fullscreen.mouse_filter = Control.MOUSE_FILTER_IGNORE;
		Subtitles.mouse_filter = Control.MOUSE_FILTER_IGNORE;
		Cursor_Style.mouse_filter = Control.MOUSE_FILTER_IGNORE;
		Youtube_Layout_Button.mouse_filter = Control.MOUSE_FILTER_IGNORE;
		Dark_Mode.mouse_filter = Control.MOUSE_FILTER_IGNORE;
		Back_Button.mouse_filter = Control.MOUSE_FILTER_IGNORE;
		if Youtube_Scroll != null:
			Youtube_Scroll._apply_settings();
		if Youtube_Layout_Top != null:
			Youtube_Layout_Top._apply_settings();
		if Youtube_Layout != null:
			Youtube_Layout._apply_settings();
		if Subtitles_BG != null:
			Subtitles_BG._apply_settings();
		Animation_Manager_Options = "Options";

func _on_options_sequens_animation_finished(anim_name: StringName) -> void:
	if anim_name == "Options":
		Quit_Button.mouse_filter = Control.MOUSE_FILTER_IGNORE;
		Option_Button.mouse_filter = Control.MOUSE_FILTER_IGNORE;
		Back_Button.mouse_filter = Control.MOUSE_FILTER_STOP;
		Subtitles.mouse_filter = Control.MOUSE_FILTER_STOP;
		Fullscreen.mouse_filter = Control.MOUSE_FILTER_STOP;
		Cursor_Style.mouse_filter = Control.MOUSE_FILTER_STOP;
		Youtube_Layout_Button.mouse_filter = Control.MOUSE_FILTER_STOP;
		Dark_Mode.mouse_filter = Control.MOUSE_FILTER_STOP;
	else:
		Quit_Button.mouse_filter = Control.MOUSE_FILTER_STOP;
		Option_Button.mouse_filter = Control.MOUSE_FILTER_STOP;

func _on_fullscreen_toggled(button_pressed: bool) -> void:
	if !Pause_Sequence.is_playing() && Animation_Manager_Pause == "UnPause" && Animation_Manager_Quit == "Quit" && !Quit_Sequence.is_playing() && !Options_Sequence.is_playing() && Animation_Manager_Options == "UnOptions":
		if button_pressed:
			Global.Fullscreen = true;
			DisplayServer.window_set_mode(DisplayServer.WINDOW_MODE_FULLSCREEN);
		else:
			Global.Fullscreen = false;
			DisplayServer.window_set_mode(DisplayServer.WINDOW_MODE_WINDOWED);
func _on_cursor_style_toggled(button_pressed: bool) -> void:
	if !Pause_Sequence.is_playing() && Animation_Manager_Pause == "UnPause" && Animation_Manager_Quit == "Quit" && !Quit_Sequence.is_playing() && !Options_Sequence.is_playing() && Animation_Manager_Options == "UnOptions":
		if button_pressed:
			Global.Cursor_Style = true;
			DisplayServer.cursor_set_custom_image(Mouse_Cursor);
		else:
			Global.Cursor_Style = false;
			DisplayServer.cursor_set_custom_image(null);
func _on_dark_mode_toggled(button_pressed: bool) -> void:
	if !Pause_Sequence.is_playing() && Animation_Manager_Pause == "UnPause" && Animation_Manager_Quit == "Quit" && !Quit_Sequence.is_playing() && !Options_Sequence.is_playing() && Animation_Manager_Options == "UnOptions":
		if button_pressed:
			Global.Dark_Mode = true;
		else:
			Global.Dark_Mode = false;
func _on_youtube_layout_toggled(button_pressed: bool) -> void:
	if !Pause_Sequence.is_playing() && Animation_Manager_Pause == "UnPause" && Animation_Manager_Quit == "Quit" && !Quit_Sequence.is_playing() && !Options_Sequence.is_playing() && Animation_Manager_Options == "UnOptions":
		if button_pressed:
			Global.Youtube_Layout = true;
		else:
			Global.Youtube_Layout = false;

func _on_mobile_pause_button_pressed() -> void:
	if !Pause_Sequence.is_playing() && !Quit_Sequence.is_playing() && Animation_Manager_Quit == "Quit" && !Options_Sequence.is_playing() && Animation_Manager_Options == "Options":
		get_tree().paused = true;
		if Animation_Manager_Pause == "UnPause":
			Quit_Button.mouse_filter = Control.MOUSE_FILTER_IGNORE;
			Option_Button.mouse_filter = Control.MOUSE_FILTER_IGNORE;
		Pause_Sequence.play(Animation_Manager_Pause);

func _on_subtitles_toggled(button_pressed: bool) -> void:
	if !Pause_Sequence.is_playing() && Animation_Manager_Pause == "UnPause" && Animation_Manager_Quit == "Quit" && !Quit_Sequence.is_playing() && !Options_Sequence.is_playing() && Animation_Manager_Options == "UnOptions":
		if button_pressed:
			Global.Subtitles = true;
		else:
			Global.Subtitles = false;
